@@ -227,7 +227,7 @@ class Option(collections.namedtuple("Option", "name type default min max var")):
         elif self.type in ["string", "file", "path"]:
             value = str(value)
             if "\n" in value or "\r" in value:
-                raise EngineError("invalid line-break in string option {!r}".format(self.name))
+                raise EngineError("invalid line-break in string option {!r}: {!r}".format(self.name, value))
             return value
         else:
             raise EngineError("unknown option type: {}", self.type)
@@ -243,7 +243,9 @@ class Option(collections.namedtuple("Option", "name type default min max var")):
 class Limit:
     """Search termination condition."""
 
-    def __init__(self, *, time=None, depth=None, nodes=None, mate=None, white_clock=None, black_clock=None, white_inc=None, black_inc=None, remaining_moves=None):
+    def __init__(self, *, time=None, depth=None, nodes=None, mate=None,
+                 white_clock=None, black_clock=None, white_inc=None,
+                 black_inc=None, remaining_moves=None):
         self.time = time
         self.depth = depth
         self.nodes = nodes
@@ -272,7 +274,8 @@ class PlayResult:
         self.draw_offered = draw_offered
 
     def __repr__(self):
-        return "<{} at {:#x} (move={}, ponder={}, info={}, draw_offered={})>".format(type(self).__name__, id(self), self.move, self.ponder, self.info, self.draw_offered)
+        return "<{} at {:#x} (move={}, ponder={}, info={}, draw_offered={})>".format(
+            type(self).__name__, id(self), self.move, self.ponder, self.info, self.draw_offered)
 
 
 class Info(_IntFlag):
@@ -325,13 +328,7 @@ class PovScore:
 
     def __eq__(self, other):
         try:
-            return self.relative == other.relative and self.turn == other.turn
-        except AttributeError:
-            return NotImplemented
-
-    def __ne__(self, other):
-        try:
-            return self.relative != other.relative or self.turn != other.turn
+            return (self.relative, self.turn) == (other.relative, other.turn)
         except AttributeError:
             return NotImplemented
 
@@ -566,6 +563,7 @@ class EngineProtocol(asyncio.SubprocessProtocol, metaclass=abc.ABCMeta):
         self.command = None
         self.next_command = None
 
+        self.initialized = False
         self.returncode = asyncio.Future(loop=self.loop)
 
     def connection_made(self, transport):
@@ -596,7 +594,7 @@ class EngineProtocol(asyncio.SubprocessProtocol, metaclass=abc.ABCMeta):
         stdin.write(b"\n")
 
     def pipe_data_received(self, fd, data):
-        self.buffer[fd].extend(data)
+        self.buffer[fd].extend(data.replace(b"\r\n", b"\n"))
         while b"\n" in self.buffer[fd]:
             line, self.buffer[fd] = self.buffer[fd].split(b"\n", 1)
             line = line.decode("utf-8")
@@ -661,8 +659,8 @@ class EngineProtocol(asyncio.SubprocessProtocol, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     @asyncio.coroutine
-    def _initialize(self):
-        pass
+    def initialize(self):
+        """Initializes the engine."""
 
     @abc.abstractmethod
     @asyncio.coroutine
@@ -739,7 +737,7 @@ class EngineProtocol(asyncio.SubprocessProtocol, metaclass=abc.ABCMeta):
             analysis is complete. You can permanently apply a configuration
             with :func:`~chess.engine.EngineProtocol.configure()`.
         """
-        analysis = yield from self.analysis(board, limit, game=game, info=info, root_moves=root_moves, options=options)
+        analysis = yield from self.analysis(board, limit, multipv=multipv, game=game, info=info, root_moves=root_moves, options=options)
 
         with analysis:
             yield from analysis.wait()
@@ -801,7 +799,7 @@ class EngineProtocol(asyncio.SubprocessProtocol, metaclass=abc.ABCMeta):
 
         loop = _get_running_loop()
         transport, protocol = yield from loop.subprocess_exec(cls, *command, **popen_args)
-        yield from protocol._initialize()
+        yield from protocol.initialize()
         return transport, protocol
 
 
@@ -856,6 +854,7 @@ class BaseCommand:
         assert self.state == CommandState.New
         self.state = CommandState.Active
         try:
+            self.check_initialized(engine)
             self.start(engine)
         except EngineError as err:
             self._handle_exception(engine, err)
@@ -866,11 +865,18 @@ class BaseCommand:
 
     def _line_received(self, engine, line):
         assert self.state in [CommandState.Active, CommandState.Cancelling]
-        self.line_received(engine, line)
+        try:
+            self.line_received(engine, line)
+        except EngineError as err:
+            self._handle_exception(engine, err)
 
     def cancel(self, engine):
         pass
 
+    def check_initialized(self, engine):
+        if not engine.initialized:
+            raise EngineError("tried to run command, but engine is not initialized")
+
     def start(self, engine):
         raise NotImplementedError
 
@@ -901,13 +907,18 @@ class UciProtocol(EngineProtocol):
         self.first_game = True
 
     @asyncio.coroutine
-    def _initialize(self):
+    def initialize(self):
         class Command(BaseCommand):
+            def check_initialized(self, engine):
+                if engine.initialized:
+                    raise EngineError("engine already initialized")
+
             def start(self, engine):
                 engine.send_line("uci")
 
             def line_received(self, engine, line):
                 if line == "uciok":
+                    engine.initialized = True
                     self.set_finished()
                 elif line.startswith("option "):
                     self._option(engine, line.split(" ", 1)[1])
@@ -1343,7 +1354,10 @@ def _parse_uci_info(arg, root_board, selector=INFO_ALL):
             # Ignore extra spaces. Those can not be directly discarded,
             # because they may occur in the string parameter.
             pass
-        elif token in ["depth", "seldepth", "time", "nodes", "pv", "multipv", "score", "currmove", "currmovenumber", "hashfull", "nps", "tbhits", "cpuload", "refutation", "currline", "ebf", "string"]:
+        elif token in ["depth", "seldepth", "time", "nodes", "pv", "multipv",
+                       "score", "currmove", "currmovenumber", "hashfull",
+                       "nps", "tbhits", "cpuload", "refutation", "currline",
+                       "ebf", "string"]:
             end_of_parameter()
             current_parameter = token
 
@@ -1491,8 +1505,12 @@ class XBoardProtocol(EngineProtocol):
         self.first_game = True
 
     @asyncio.coroutine
-    def _initialize(self):
+    def initialize(self):
         class Command(BaseCommand):
+            def check_initialized(self, engine):
+                if engine.initialized:
+                    raise EngineError("engine already initialized")
+
             def start(self, engine):
                 engine.send_line("xboard")
                 engine.send_line("protover 2")
@@ -1560,6 +1578,7 @@ class XBoardProtocol(EngineProtocol):
                         engine.options[name] = Option(name, "path", None, None, None, None)
                     engine.send_line("accept egt")
 
+                engine.initialized = True
                 self.set_finished()
 
         yield from self.communicate(Command)
@@ -2195,19 +2214,22 @@ class SimpleEngine:
 
     def play(self, board, limit, *, game=None, info=INFO_NONE, ponder=False, root_moves=None, options={}):
         with self._not_shut_down():
-            coro = asyncio.wait_for(self.protocol.play(board, limit, game=game, info=info, ponder=ponder, root_moves=root_moves, options=options), self._timeout_for(limit))
+            coro = self.protocol.play(board, limit, game=game, info=info, ponder=ponder, root_moves=root_moves, options=options)
+            coro = asyncio.wait_for(coro, self._timeout_for(limit))
             future = asyncio.run_coroutine_threadsafe(coro, self.protocol.loop)
         return future.result()
 
     def analyse(self, board, limit, *, multipv=None, game=None, info=INFO_ALL, root_moves=None, options={}):
         with self._not_shut_down():
-            coro = asyncio.wait_for(self.protocol.analyse(board, limit, multipv=multipv, game=game, info=info, root_moves=root_moves, options=options), self._timeout_for(limit))
+            coro = self.protocol.analyse(board, limit, multipv=multipv, game=game, info=info, root_moves=root_moves, options=options)
+            coro = asyncio.wait_for(coro, self._timeout_for(limit))
             future = asyncio.run_coroutine_threadsafe(coro, self.protocol.loop)
         return future.result()
 
     def analysis(self, board, limit=None, *, multipv=None, game=None, info=INFO_ALL, root_moves=None, options={}):
         with self._not_shut_down():
-            coro = asyncio.wait_for(self.protocol.analysis(board, limit, multipv=multipv, game=game, info=info, root_moves=root_moves, options=options), self.timeout)
+            coro = self.protocol.analysis(board, limit, multipv=multipv, game=game, info=info, root_moves=root_moves, options=options)
+            coro = asyncio.wait_for(coro, self.timeout)
             future = asyncio.run_coroutine_threadsafe(coro, self.protocol.loop)
         return SimpleAnalysisResult(self, future.result())
 
